.. warning::
    Client version 2 is obsolete, please use Client version 3 instead.


Entities
========

Represents domain objects like project or build.
The user of ``python-copr`` is not expected to use the directly.

.. automodule:: copr.client_v2.entities
    :members:
    :undoc-members:
    :show-inheritance:
